==> haskell-aeson-1.4.2.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.4.2.0
id: aeson-1.4.2.0-3Fy8y4TZyLW38WYgCKr7yc
key: aeson-1.4.2.0-3Fy8y4TZyLW38WYgCKr7yc
license: BSD-3-Clause
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
abi: da95d2cf44878ac639fcd049baa58446
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.QQ.Simple Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types
hidden-modules: Data.Aeson.Compat Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Unescape
                Data.Aeson.Parser.Time Data.Aeson.Types.FromJSON
                Data.Aeson.Types.Generic Data.Aeson.Types.ToJSON
                Data.Aeson.Types.Class Data.Aeson.Types.Internal
                Data.Attoparsec.Time Data.Attoparsec.Time.Internal
                Data.Aeson.Parser.UnescapePure
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-1.4.2.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-1.4.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-1.4.2.0
hs-libraries: HSaeson-1.4.2.0-3Fy8y4TZyLW38WYgCKr7yc
depends:
    attoparsec-0.13.2.2-4iFLH0ONEYhG16eDwwtqQO base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    text-1.2.3.1 th-abstraction-0.2.11.0-DAhuCgi08HTBWsDjm9nrOq
    time-1.8.0.2 time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-1.4.2.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.4.2.0
id: aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
key: aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
license: BSD-3-Clause
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
abi: 1557a0854590f45b1cc4c49624f7a2d9
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.QQ.Simple Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types
hidden-modules: Data.Aeson.Compat Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Unescape
                Data.Aeson.Parser.Time Data.Aeson.Types.FromJSON
                Data.Aeson.Types.Generic Data.Aeson.Types.ToJSON
                Data.Aeson.Types.Class Data.Aeson.Types.Internal
                Data.Attoparsec.Time Data.Attoparsec.Time.Internal
                Data.Aeson.Parser.UnescapePure
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-1.4.2.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-1.4.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-1.4.2.0
hs-libraries: HSaeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
depends:
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    text-1.2.3.1 th-abstraction-0.2.11.0-DAhuCgi08HTBWsDjm9nrOq
    time-1.8.0.2 time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
